# admin_bot.py

import telebot
from telebot import types
import mysql.connector
import datetime
import logging
import json
from urllib.parse import unquote
import time
import threading
from config import ADMIN_BOT_TOKEN, DB_CONFIG, ADMIN_IDS
from database import connect_to_database
from sms import send_sms

# تنظیم لاگینگ
logging.basicConfig(filename='admin_bot_log.txt', level=logging.ERROR,
                   format='%(asctime)s - %(levelname)s - %(message)s')

# توکن ربات ادمین
admin_bot = telebot.TeleBot(ADMIN_BOT_TOKEN)

# دیکشنری برای نگهداری وضعیت موقت
admin_states = {}

def notify_user(user_telegram_id, message):
    """ارسال پیام به کاربر از طریق ربات اصلی"""
    try:
        conn = connect_to_database()
        if conn:
            cursor = conn.cursor()
            cursor.execute(
                "INSERT INTO notifications (user_id, message, status) VALUES (%s, %s, 'pending')",
                (user_telegram_id, message)
            )
            conn.commit()
            conn.close()
            return True
    except Exception as e:
        logging.error(f"خطا در ارسال نوتیفیکیشن: {e}")
        return False

def is_admin(user_id):
    """بررسی ادمین بودن کاربر"""
    return user_id in ADMIN_IDS

@admin_bot.message_handler(commands=['start'])
def admin_start(message):
    """شروع ربات ادمین"""
    if not is_admin(message.from_user.id):
        admin_bot.reply_to(message, "⛔️ شما دسترسی به پنل ادمین ندارید.")
        return

    markup = types.ReplyKeyboardMarkup(resize_keyboard=True, row_width=2)
    markup.add(
        types.KeyboardButton("📋 درخواست‌های جدید"),
        types.KeyboardButton("🔄 درخواست‌های در حال بررسی"),
        types.KeyboardButton("✅ درخواست‌های تایید شده"),
        types.KeyboardButton("❌ درخواست‌های رد شده"),
        types.KeyboardButton("📊 گزارش‌گیری")
    )

    admin_bot.reply_to(message, "👮‍♂️ به پنل مدیریت خوش آمدید", reply_markup=markup)

def get_request_details(request):
    """تهیه متن جزئیات درخواست"""
    return f"""
📝 اطلاعات درخواست

👤 نام: {request['first_name']}
👥 نام خانوادگی: {request['last_name']}
🆔 کد ملی: {request['national_id']}
📱 موبایل: {request['phone']}
📅 تاریخ تولد: {request['birth_date']}
🎫 کد پیگیری: {request['tracking_code']}

🔗 لینک‌ها:
1️⃣ متقاضی: {unquote(request['verification_link1'])}
2️⃣ ضامن اول: {unquote(request['verification_link2'])}
3️⃣ ضامن دوم: {unquote(request['verification_link3'])}

📅 تاریخ ثبت: {request['registration_date'].strftime('%Y-%m-%d %H:%M:%S')}
"""

def get_admin_markup(telegram_id):
    """ایجاد دکمه‌های مدیریتی برای هر درخواست"""
    markup = types.InlineKeyboardMarkup(row_width=2)
    markup.add(
        types.InlineKeyboardButton("✅ تایید", callback_data=f"approve_{telegram_id}"),
        types.InlineKeyboardButton("❌ رد", callback_data=f"reject_{telegram_id}")
    )
    markup.add(
        types.InlineKeyboardButton("🔄 نیاز به اصلاح", callback_data=f"correction_{telegram_id}"),
        types.InlineKeyboardButton("🚫 مسدود", callback_data=f"block_{telegram_id}")
    )
    return markup

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "📋 درخواست‌های جدید")
def show_new_requests(message):
    """نمایش درخواست‌های جدید"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT * FROM users
            WHERE status = 'pending'
            ORDER BY registration_date DESC
        """)
        requests = cursor.fetchall()
        conn.close()

        if not requests:
            admin_bot.reply_to(message, "❌ درخواست جدیدی وجود ندارد")
            return

        for req in requests:
            text = get_request_details(req)
            markup = get_admin_markup(req['telegram_id'])
            admin_bot.send_message(message.chat.id, text, reply_markup=markup)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "🔄 درخواست‌های در حال بررسی")
def show_in_progress_requests(message):
    """نمایش درخواست‌های در حال بررسی"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT * FROM users
            WHERE status = 'needs_correction'
            ORDER BY last_update DESC
        """)
        requests = cursor.fetchall()
        conn.close()

        if not requests:
            admin_bot.reply_to(message, "❌ درخواستی در حال بررسی نیست")
            return

        for req in requests:
            text = get_request_details(req)
            markup = get_admin_markup(req['telegram_id'])
            admin_bot.send_message(message.chat.id, text, reply_markup=markup)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "✅ درخواست‌های تایید شده")
def show_approved_requests(message):
    """نمایش درخواست‌های تایید شده"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT * FROM users
            WHERE status = 'approved'
            ORDER BY last_update DESC
            LIMIT 20
        """)
        requests = cursor.fetchall()
        conn.close()

        if not requests:
            admin_bot.reply_to(message, "❌ درخواست تایید شده‌ای وجود ندارد")
            return

        for req in requests:
            text = get_request_details(req)
            admin_bot.send_message(message.chat.id, text)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "❌ درخواست‌های رد شده")
def show_rejected_requests(message):
    """نمایش درخواست‌های رد شده"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT * FROM users
            WHERE status = 'rejected'
            ORDER BY last_update DESC
            LIMIT 20
        """)
        requests = cursor.fetchall()
        conn.close()

        if not requests:
            admin_bot.reply_to(message, "❌ درخواست رد شده‌ای وجود ندارد")
            return

        for req in requests:
            text = get_request_details(req)
            admin_bot.send_message(message.chat.id, text)

@admin_bot.callback_query_handler(func=lambda call: True)
def handle_admin_callback(call):
    """مدیریت دکمه‌های ادمین"""
    try:
        action, user_id = call.data.split('_')
        user_id = int(user_id)

        if action == "message":
            # حالت ارسال پیام به کاربر
            admin_states[call.from_user.id] = {"action": "send_message", "user_id": user_id}
            msg = admin_bot.send_message(call.message.chat.id, "💬 پیام خود را برای کاربر وارد کنید:")
            admin_bot.register_next_step_handler(msg, process_admin_message)
            return

        elif action == "history":
            # نمایش سوابق کاربر
            show_user_history(call.message.chat.id, user_id)
            return

        status_map = {
            'approve': ('approved', '✅ درخواست شما تایید شد.'),
            'reject': ('rejected', '❌ درخواست شما رد شد.'),
            'correction': ('needs_correction', '🔄 درخواست شما نیاز به اصلاح دارد.'),
            'block': ('blocked', '🚫 دسترسی شما به ربات مسدود شد.')
        }

        if action in status_map:
            status, message = status_map[action]
            conn = connect_to_database()
            if conn:
                cursor = conn.cursor()
                cursor.execute(
                    "UPDATE users SET status = %s WHERE telegram_id = %s",
                    (status, user_id)
                )
                conn.commit()
                conn.close()

                # ارسال نوتیفیکیشن به کاربر
                notify_user(user_id, message)

                admin_bot.answer_callback_query(
                    call.id,
                    f"✅ وضعیت کاربر به {status} تغییر کرد"
                )
                admin_bot.edit_message_reply_markup(
                    call.message.chat.id,
                    call.message.message_id,
                    reply_markup=None
                )

                # ارسال پیامک تأیید یا رد درخواست
                phone_number = get_user_phone(user_id)
                if phone_number:
                    sms_message = message
                    send_sms(phone_number, sms_message, body_id=1)  # فرض کنید body_id=1 برای متن پیشفرض تأیید یا رد درخواست است

    except Exception as e:
        logging.error(f"خطا در پردازش کالبک: {e}")
        admin_bot.answer_callback_query(call.id, "❌ خطا در انجام عملیات")

def get_user_phone(user_id):
    """بازیابی شماره تلفن کاربر از دیتابیس"""
    try:
        conn = connect_to_database()
        if conn:
            cursor = conn.cursor()
            cursor.execute("SELECT phone FROM users WHERE telegram_id = %s", (user_id,))
            result = cursor.fetchone()
            conn.close()
            return result[0] if result else None
    except Exception as e:
        logging.error(f"خطا در بازیابی شماره تلفن کاربر: {e}")
        return None

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "📊 گزارش‌گیری")
def show_report_menu(message):
    """نمایش منوی گزارش‌گیری"""
    markup = types.ReplyKeyboardMarkup(resize_keyboard=True, row_width=2)
    markup.add(
        types.KeyboardButton("📅 گزارش امروز"),
        types.KeyboardButton("📆 گزارش با تاریخ"),
        types.KeyboardButton("📈 گزارش بازه زمانی"),
        types.KeyboardButton("👥 آمار کلی کاربران"),
        types.KeyboardButton("🏠 بازگشت به منوی اصلی")
    )
    admin_bot.reply_to(message, "📊 لطفا نوع گزارش را انتخاب کنید:", reply_markup=markup)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "📅 گزارش امروز")
def show_today_report(message):
    """نمایش گزارش امروز"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT
                COUNT(*) as total,
                SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending,
                SUM(CASE WHEN status = 'approved' THEN 1 ELSE 0 END) as approved,
                SUM(CASE WHEN status = 'rejected' THEN 1 ELSE 0 END) as rejected,
                SUM(CASE WHEN status = 'needs_correction' THEN 1 ELSE 0 END) as correction,
                SUM(CASE WHEN status = 'blocked' THEN 1 ELSE 0 END) as blocked
            FROM users
            WHERE DATE(registration_date) = CURDATE()
        """)
        stats = cursor.fetchone()
        conn.close()

        report = f"""
📊 گزارش امروز:

👥 کل درخواست‌ها: {stats['total'] or 0}
⏳ در حال بررسی: {stats['pending'] or 0}
✅ تایید شده: {stats['approved'] or 0}
❌ رد شده: {stats['rejected'] or 0}
🔄 نیاز به اصلاح: {stats['correction'] or 0}
🚫 مسدود شده: {stats['blocked'] or 0}
"""
        admin_bot.reply_to(message, report)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "📆 گزارش با تاریخ")
def ask_report_date(message):
    """درخواست تاریخ برای گزارش"""
    msg = admin_bot.reply_to(message, "📅 لطفا تاریخ مورد نظر را وارد کنید (مثال: 1403/04/21):")
    admin_bot.register_next_step_handler(msg, show_date_report)

def show_date_report(message):
    """نمایش گزارش تاریخ خاص"""
    try:
        date_str = message.text
        year, month, day = map(int, date_str.split('/'))

        conn = connect_to_database()
        if conn:
            cursor = conn.cursor(dictionary=True)
            cursor.execute("""
                SELECT
                    COUNT(*) as total,
                    SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending,
                    SUM(CASE WHEN status = 'approved' THEN 1 ELSE 0 END) as approved,
                    SUM(CASE WHEN status = 'rejected' THEN 1 ELSE 0 END) as rejected,
                    SUM(CASE WHEN status = 'needs_correction' THEN 1 ELSE 0 END) as correction,
                    SUM(CASE WHEN status = 'blocked' THEN 1 ELSE 0 END) as blocked
                FROM users
                WHERE DATE(registration_date) = %s
            """, (f"{year:04d}-{month:02d}-{day:02d}",))
            stats = cursor.fetchone()
            conn.close()

            report = f"""
📊 گزارش تاریخ {date_str}:

👥 کل درخواست‌ها: {stats['total'] or 0}
⏳ در حال بررسی: {stats['pending'] or 0}
✅ تایید شده: {stats['approved'] or 0}
❌ رد شده: {stats['rejected'] or 0}
🔄 نیاز به اصلاح: {stats['correction'] or 0}
🚫 مسدود شده: {stats['blocked'] or 0}
"""
            admin_bot.reply_to(message, report)

    except:
        admin_bot.reply_to(message, "❌ لطفا تاریخ را با فرمت صحیح وارد کنید (مثال: 1403/04/21)")

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "📈 گزارش بازه زمانی")
def ask_date_range(message):
    """درخواست بازه زمانی برای گزارش"""
    msg = admin_bot.reply_to(message, "📅 لطفا تاریخ شروع و پایان را وارد کنید (مثال: 1403/04/21 1403/04/25):")
    admin_bot.register_next_step_handler(msg, show_date_range_report)

def show_date_range_report(message):
    """نمایش گزارش بازه زمانی"""
    try:
        start_date_str, end_date_str = message.text.split()
        start_year, start_month, start_day = map(int, start_date_str.split('/'))
        end_year, end_month, end_day = map(int, end_date_str.split('/'))

        conn = connect_to_database()
        if conn:
            cursor = conn.cursor(dictionary=True)
            cursor.execute("""
                SELECT
                    COUNT(*) as total,
                    SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending,
                    SUM(CASE WHEN status = 'approved' THEN 1 ELSE 0 END) as approved,
                    SUM(CASE WHEN status = 'rejected' THEN 1 ELSE 0 END) as rejected,
                    SUM(CASE WHEN status = 'needs_correction' THEN 1 ELSE 0 END) as correction,
                    SUM(CASE WHEN status = 'blocked' THEN 1 ELSE 0 END) as blocked
                FROM users
                WHERE DATE(registration_date) BETWEEN %s AND %s
            """, (f"{start_year:04d}-{start_month:02d}-{start_day:02d}",
                  f"{end_year:04d}-{end_month:02d}-{end_day:02d}"))
            stats = cursor.fetchone()
            conn.close()

            report = f"""
📊 گزارش از تاریخ {start_date_str} تا {end_date_str}:

👥 کل درخواست‌ها: {stats['total'] or 0}
⏳ در حال بررسی: {stats['pending'] or 0}
✅ تایید شده: {stats['approved'] or 0}
❌ رد شده: {stats['rejected'] or 0}
🔄 نیاز به اصلاح: {stats['correction'] or 0}
🚫 مسدود شده: {stats['blocked'] or 0}
"""
            admin_bot.reply_to(message, report)

    except:
        admin_bot.reply_to(message, "❌ لطفا تاریخ‌ها را با فرمت صحیح وارد کنید (مثال: 1403/04/21 1403/04/25)")

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "👥 آمار کلی کاربران")
def show_total_stats(message):
    """نمایش آمار کلی کاربران"""
    conn = connect_to_database()
    if conn:
        cursor = conn.cursor(dictionary=True)
        cursor.execute("""
            SELECT
                COUNT(*) as total,
                SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending,
                SUM(CASE WHEN status = 'approved' THEN 1 ELSE 0 END) as approved,
                SUM(CASE WHEN status = 'rejected' THEN 1 ELSE 0 END) as rejected,
                SUM(CASE WHEN status = 'needs_correction' THEN 1 ELSE 0 END) as correction,
                SUM(CASE WHEN status = 'blocked' THEN 1 ELSE 0 END) as blocked
            FROM users
        """)
        stats = cursor.fetchone()

        # آمار اضافی
        cursor.execute("SELECT COUNT(DISTINCT telegram_id) as unique_users FROM users")
        unique_stats = cursor.fetchone()

        conn.close()

        report = f"""
📊 آمار کلی کاربران:

👥 کل کاربران یکتا: {unique_stats['unique_users'] or 0}
📝 کل درخواست‌ها: {stats['total'] or 0}
⏳ در حال بررسی: {stats['pending'] or 0}
✅ تایید شده: {stats['approved'] or 0}
❌ رد شده: {stats['rejected'] or 0}
🔄 نیاز به اصلاح: {stats['correction'] or 0}
🚫 مسدود شده: {stats['blocked'] or 0}
"""
        admin_bot.reply_to(message, report)

@admin_bot.message_handler(func=lambda message: is_admin(message.from_user.id) and message.text == "🏠 بازگشت به منوی اصلی")
def back_to_main_menu(message):
    """بازگشت به منوی اصلی"""
    markup = types.ReplyKeyboardMarkup(resize_keyboard=True, row_width=2)
    markup.add(
        types.KeyboardButton("📋 درخواست‌های جدید"),
        types.KeyboardButton("🔄 درخواست‌های در حال بررسی"),
        types.KeyboardButton("✅ درخواست‌های تایید شده"),
        types.KeyboardButton("❌ درخواست‌های رد شده"),
        types.KeyboardButton("📊 گزارش‌گیری"),
        types.KeyboardButton("👥 مدیریت کاربران")
    )
    admin_bot.reply_to(message, "👮‍♂️ به منوی اصلی بازگشتید", reply_markup=markup)

# شروع ربات ادمین
if __name__ == "__main__":
    try:
        print("✅ ربات ادمین شروع به کار کرد...")
        admin_bot.infinity_polling(timeout=10, long_polling_timeout=5)
    except Exception as e:
        logging.error(f"خطا در اجرای ربات ادمین: {e}")
